@@ -6,13 +6,14 @@
 ##' @param INDICES Indices (vector or list of indices, vector of column names, or formula of column names)
 ##' @param FUN A function to be applied to data frame subsets of 'data'.
 ##' @param COLUMNS (Optional) subset of columns of x to work on
+##' @param array if TRUE an array/matrix is always returned
 ##' @param ... Additional arguments to lower-level functions
 ##' @author Klaus K. Holst
 ##' @export
 ##' @examples
 ##' By(datasets::CO2,~Treatment+Type,colMeans,~conc)
 ##' By(datasets::CO2,~Treatment+Type,colMeans,~conc+uptake)
-By <- function(x,INDICES,FUN,COLUMNS,...) {
+By <- function(x,INDICES,FUN,COLUMNS,array=FALSE,...) {
     if (inherits(INDICES,"formula")) {
         INDICES <- as.list(model.frame(INDICES,x))
     } else {
@@ -20,7 +21,6 @@ By <- function(x,INDICES,FUN,COLUMNS,...) {
             INDICES <- as.list(x[,INDICES,drop=FALSE])
         }
     }
-    ##  array(by(d0$Age,list(d0$T_Stage,d0$Sex),mean,simplify=TRUE),)
     if (!missing(COLUMNS)) {
         if (inherits(COLUMNS,"formula")) {
             x <- model.frame(COLUMNS,x)
@@ -28,10 +28,12 @@ By <- function(x,INDICES,FUN,COLUMNS,...) {
             x <- x[,COLUMNS,drop=FALSE]
         }
     }
-    a <- by(x, INDICES, FUN=FUN, ...)    
-    if (NCOL(x)==1) {
+    a <- by(x, INDICES, FUN=FUN, ...)
+    if (NCOL(x)==1 && !array) {        
+        ##DimElem <- length(a[rep(1,length(dim(a)))][[1]])        
         a <- a[]
         attr(a,"call") <- NULL
+        ##        a <- array(a,)
     }
     return(a)
 }
