@@ -54,6 +54,10 @@ normal.lvm <- function(link="identity",mean,sd,log=FALSE,...) {
 ##' @export
 gaussian.lvm <- normal.lvm
 
+##' @export
+lognormal.lvm <- function(...) normal.lvm(...,log=TRUE)
+
+
 ###}}} normal/gaussian
 
 ###{{{ poisson
@@ -115,6 +119,7 @@ probit.lvm <- binomial.lvm("probit")
 
 ###{{{ Gamma
 
+
 ##' @export
 Gamma.lvm <- function(link="inverse",shape,rate,unit=FALSE,var=FALSE,log=FALSE,...) {
   fam <- Gamma(link); fam$link <- link
@@ -148,6 +153,10 @@ Gamma.lvm <- function(link="inverse",shape,rate,unit=FALSE,var=FALSE,log=FALSE,.
   return(f)  
 } 
 
+##' @export
+loggamma.lvm <- function(...) Gamma.lvm(...,log=TRUE)
+
+
 ###}}} Gamma
 
 ###{{{ student (t-distribution)
@@ -211,3 +220,24 @@ weibull.lvm <- function(scale=1.25,shape=2,cens=Inf,breakties=0) {
 }
 
 ###}}} weibull
+
+###{{{ sequence
+##' @export
+sequence.lvm <- function(a=0,b=1) {
+    f <- function(n,...)
+      seq(a,b,length.out=n)
+  return(f)
+}
+###}}} sequence
+
+###{{{ ones
+##' @export
+ones.lvm <- function(fraction=0) {
+    f <- function(n,...) {
+        val <- rep(1,n)
+        if (fraction>0 && fraction<1) val[seq(n*(1-fraction))] <- 0
+        val
+        }
+  return(f)
+}
+###}}} ones
