@@ -22,9 +22,10 @@ function(x, ...) {
 ##      if (!(y %in% endogenous(m)))
       {
         col1 <- as.character(oneline)
+        
         D <- attributes(distribution(x)[[y]])$family
         col2 <- x$attributes$type[y]
-        if (is.null(col2) || is.na(col2)) col2 <- "Normal"
+        if (is.null(col2) || is.na(col2)) col2 <- "Gaussian"
         if (!is.null(D$family)) col2 <- paste(D$family,sep="")
         if (!is.null(D$link)) col2 <- paste(col2,"(",D$link,")",sep="")
         if (!is.null(D$par)) col2 <- paste(col2,"(",paste(D$par,collapse=","),")",sep="")
